Cogs

Struct Cogs 

pub struct Cogs { /* private fields */ }
COGS measurements collector.

The collector is cheap to clone.

Implementations

Source

impl Cogs

pub fn new<T>(recorder: T) -> Self
where T: CogsRecorder + 'static,

Creates a new Cogs from a recorder.

pub fn noop() -> Self

Shortcut for creating a Cogs from a crate::NoopRecorder.

All collected measurements will be dropped.

Source

impl Cogs

pub fn timed<F: Into<FeatureWeights>>( &self, resource: ResourceId, weights: F, ) -> Token

Starts a recording for a COGS measurement, using the SystemClock.

When the returned token is dropped the measurement will be recorded with the configured recorder.

The recorded measurement can be attributed to multiple features by supplying a weighted FeatureWeights. A single AppFeature attributes the entire measurement to the feature.

See also: Self::timed_with.

Example:
fn process_span(cogs: &Cogs, span: &mut Span) {
    let _token = cogs.timed(ResourceId::Relay, AppFeature::Spans);

    scrub_sql(span);
    extract_tags(span);
}
pub fn timed_with<F: Into<FeatureWeights>, C: Clock>( &self, resource: ResourceId, weights: F, clock: C, ) -> Token<C>

Starts a recording for a COGS measurement with a specific Clock.

When the returned token is dropped the measurement will be recorded with the configured recorder.

The recorded measurement can be attributed to multiple features by supplying a weighted FeatureWeights. A single AppFeature attributes the entire measurement to the feature.

Example:
fn process_span(cogs: &Cogs, span: &mut Span) {
    let _token = cogs.timed_with(ResourceId::Relay, AppFeature::Spans, CustomClock);

    scrub_sql(span);
    extract_tags(span);
}