pub struct Token<C: Clock = SystemClock> { /* private fields */ }Expand description
An in progress COGS measurement.
The measurement is recorded when the token is dropped.
Implementations
Sourceimpl<C: Clock> Token<C>
impl<C: Clock> Token<C>
Sourcepub fn noop() -> Selfwhere
C: Default,
pub fn noop() -> Selfwhere
C: Default,
Creates a new no-op token, which records nothing.
This is primarily useful for testing.
Sourcepub fn start_category(
&mut self,
category: impl Category,
) -> CategoryToken<'_, C>
pub fn start_category( &mut self, category: impl Category, ) -> CategoryToken<'_, C>
Starts a categorized measurement.
The measurement is finalized when the returned CategoryToken is dropped.
Instead of manually starting a categorized measurement, the crate::with
macro can be used.
Sourcepub fn update<T: Into<FeatureWeights>>(&mut self, features: T)
pub fn update<T: Into<FeatureWeights>>(&mut self, features: T)
Updates the app features to which the active measurement is attributed to.
Example:
fn process(cogs: &Cogs, item: &Item) {
let mut token = cogs.timed(ResourceId::Relay, AppFeature::Unattributed);
// App feature is only known after some computations.
if do_something(item) {
token.update(AppFeature::Spans);
} else {
token.update(AppFeature::Transactions);
}
}Trait Implementations